/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#include <glibmm/i18n.h>
#include <gtkmm/messagedialog.h>
#include <gtkmm/main.h>
#include "DisclaimerDialog.h"

DisclaimerDialog::DisclaimerDialog(std::string *GladeFilename)
{
	try
	{
		refXml = Gnome::Glade::Xml::create(*GladeFilename, "DisclaimerDialog");
	}
	catch (const Gnome::Glade::XmlError& ex)
	{
		Gtk::MessageDialog *message = new Gtk::MessageDialog(_("Error reading data file: ")+*GladeFilename+"\n"+_("Program cannot continue."),
			false,Gtk::MESSAGE_ERROR,Gtk::BUTTONS_CANCEL,true);
		message->run();
		InitFailure=true;
		GtkDialog=false;
		return;
	}

	refXml->get_widget("DisclaimerDialog",GtkDialog);
	refXml->get_widget("CancelButton",CancelButton);
	refXml->get_widget("AgreeButton",AgreeButton);

	/* Set the default icon */
	try {
		Glib::RefPtr<Gdk::Pixbuf> appicon = Gdk::Pixbuf::create_from_file(std::string(PACKAGEDATADIR)+"/../pixmaps/vifiricon.png");
		GtkDialog->set_icon(appicon);
		GtkDialog->set_default_icon(appicon);
	}
	catch (const Glib::FileError& ex) { /* Ignore errors */}

	CancelButton->signal_clicked().connect(sigc::mem_fun(this,&DisclaimerDialog::on_Cancel_clicked));
	AgreeButton->signal_clicked().connect(sigc::mem_fun(this,&DisclaimerDialog::on_Agree_clicked));

	GtkDialog->set_deletable(false);
	GtkDialog->show();
	InitFailure=false;
}

DisclaimerDialog::~DisclaimerDialog() {
	delete GtkDialog;
}

int DisclaimerDialog::Run() {
	return GtkDialog->run();
}

void DisclaimerDialog::on_Cancel_clicked() {
	GtkDialog->response(false);
}

void DisclaimerDialog::on_Agree_clicked() {
	GtkDialog->response(true);
}

bool DisclaimerDialog::GetInitFailure() {
	return InitFailure;
}
