/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifndef NFD_H_
#define NFD_H_

#include <string>
#include <vector>
#include <fstream>
#include <iostream>
#include <time.h>
#include "Config.h"
#include "Airport.h"
#include "NavAid.h"
#include "EnrouteWaypoint.h"

class NFD
{
public:
	NFD();
	~NFD();

	bool ParseHeader(std::ifstream *IFStream);
	void StoreLine(char *Line);
	void ReserveLines();
	void FreeLines();
	bool ParseAirportLine(std::vector<std::string>::iterator AirportLinei, std::vector<Airport*> *Airports);
	bool ParseRunwayLine(std::vector<std::string>::iterator RunwayLinei, std::vector<Airport*> *Airports);
	bool ParseVORLine(std::vector<std::string>::iterator VORLinei, std::vector<NavAid*> *NavAids);
	bool ParseNDBLine(std::vector<std::string>::iterator NDBLinei, std::vector<NavAid*> *NavAids);
	bool ParseEnrouteWaypointLine(std::vector<std::string>::iterator EnrouteWaypointLinei, std::vector<EnrouteWaypoint*> *EnrouteWaypoints);
	std::vector<std::string> *GetAirportLines();
	std::vector<std::string> *GetRunwayLines();
	std::vector<std::string> *GetVORLines();
	std::vector<std::string> *GetNDBLines();
	std::vector<std::string> *GetEnrouteWaypointLines();
	std::string GetVolume();

private:
	std::vector<std::string> AirportLines;
	std::vector<std::string> RunwayLines;
	std::vector<std::string> VORLines;
	std::vector<std::string> NDBLines;
	std::vector<std::string> EnrouteWaypointLines;
	std::string Volume;
	int CRC;	/* Currently unchecked */
};

#endif /*NFD_H_*/
