/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifndef ROUTE_H_
#define ROUTE_H_

#include <list>
#include <gtkmm/window.h>
#include "RoutePoint.h"
#include "SectionalChart.h"
#include "CRC32.h"
#include "Airport.h"

#define ROUTE_FILEMAGIC "Vifir_Route"

class Route
{
public:
	Route();
	void Add(RoutePoint *RP);
	void Del(std::list<RoutePoint*>::iterator RPi);
	void Shift(std::list<RoutePoint*>::iterator RPi, int Direction);
	void Reverse();
	std::list<RoutePoint*> *GetRoutePoints();
	std::list<RoutePoint*> *GetLinearRoutePoints();
	std::string GetFilename();
	bool MakeBinary(struct Route_Binary_struct *BinaryData);
	void SetFromBinary(struct Route_Binary_struct *BinaryData);
	bool Load(std::string Filename);
	bool Load();
	void Save(std::string Filename);
	void Save();
	bool GetChanged();
	void Clear();
	void ClearLinRoutePoints();

private:
	void ComputeLinRoutePoints();
	void LoadRoutePoint(std::list<RoutePoint*> *RoutePointV,std::ifstream *ifs, uint32_t *RunningCRC);
	void SaveRoutePoints(std::list<RoutePoint*> *RoutePointV, std::ofstream *ofs, uint32_t *RunningSize, uint32_t *RunningCRC);

	std::list<RoutePoint*> RoutePoints;
	std::list<RoutePoint*> LinRoutePoints;
	CRC32 CRC;
	std::string Filename;
};

/* Increment the version when the data structure changes */
#define ROUTE_HEADER_STRUCT_VER 1
#ifdef WIN32
#pragma pack(1)
#endif
struct Route_Header_struct {
	char Magic[sizeof(ROUTE_FILEMAGIC)];
	uint32_t DataVersion;
	uint32_t FileSize;
	uint32_t CRC32;	/* Computed with this field and FileSize set to zero */
	uint32_t nRoutePoints;
}
#ifndef WIN32
        __attribute__ ((packed))
#endif
;
#ifdef WIN32
#pragma pack()
#endif

/* Increment the version when the structure changes */
#define ROUTE_BINARY_STRUCT_VER 1
#ifdef WIN32
#pragma pack(1)
#endif
struct Route_Binary_struct {
}
#ifndef WIN32
        __attribute__ ((packed))
#endif
;
#ifdef WIN32
#pragma pack()
#endif

#endif /*ROUTE_H_*/
