/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifndef WAYPOINT_H_
#define WAYPOINT_H_

#include <string>
#include <time.h>
#include <stdint.h>
#include <math.h>

#ifdef HAVE_CONFIG_H
# include "../config.h"
#endif

#ifdef HAVE_LIBNOVA
# include <libnova/solar.h>
# include <libnova/julian_day.h>
# include <libnova/rise_set.h>
#endif

class Waypoint
{
public:
	enum LocType_enum {
		LOC_UNKNOWN,
		LOC_AIRPORT,
		LOC_NAVAID,
		LOC_ENROUTEWAYPOINT
	};

	Waypoint();

	double GetLon();
	double GetLat();
	std::string GetID();
	void SetLonLat(double Lon, double Lat);
	bool Matchi(std::string Str);
	enum LocType_enum GetLocType();
	std::string GetLocTypeStr(enum LocType_enum LocType);
	std::string GetLocTypeStr();
	std::string GetName();
#ifdef HAVE_LIBNOVA
	time_t GetMornCivilTwilight();
	time_t GetSunrise();
	time_t GetSunset();
	time_t GetEveCivilTwilight();
#endif
	bool MakeBinary(struct Waypoint_Binary_struct *BinaryData);
	void SetFromBinary(struct Waypoint_Binary_struct *BinaryData);

protected:
	std::string ID;
	std::string Name;
	double Lon,Lat;
	enum LocType_enum LocType;
};

/* Increment the version when the structure changes */
#define WAYPOINT_BINARY_STRUCT_VER 1
#ifdef WIN32
#pragma pack(1)
#endif
struct Waypoint_Binary_struct {
	char ID[5];
	char Name[50];
	int32_t Lonx1000000,Latx1000000;
	uint8_t LocType;
}
#ifndef WIN32
        __attribute__ ((packed))
#endif
;
#ifdef WIN32
#pragma pack()
#endif

#endif /*WAYPOINT_H_*/
