/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#include <glibmm/i18n.h>
#include <gtkmm/messagedialog.h>
#include <gtkmm/main.h>
#include "WelcomeDialog.h"

WelcomeDialog::WelcomeDialog(std::string *GladeFilename, Config *Cfg)
{
	try
	{
		refXml = Gnome::Glade::Xml::create(*GladeFilename, "WelcomeDialog");
	}
	catch (const Gnome::Glade::XmlError& ex)
	{
		Gtk::MessageDialog *message = new Gtk::MessageDialog(_("Error reading data file: ")+*GladeFilename+"\n"+_("Program cannot continue."),
			false,Gtk::MESSAGE_ERROR,Gtk::BUTTONS_CANCEL,true);
		message->run();
		Gtk::Main::quit();
		return;
	}

	refXml->get_widget("WelcomeDialog",GtkDialog);

	refXml->get_widget("ShowButton",ShowButton);
	refXml->get_widget("LogoImage",LogoImage);

	/* Set the Logo image */
	try {
		LogoImage->set(std::string(PACKAGEDATADIR)+"/../pixmaps/vifiricon.png");
	}
	catch (const Glib::FileError& ex) { /* Ignore errors */}

	this->Cfg=Cfg;
}

WelcomeDialog::~WelcomeDialog() {
	delete GtkDialog;
}

int WelcomeDialog::Run() {
	int Result;

	Result=GtkDialog->run();
	Cfg->SetShowWelcomeOnStartup(ShowButton->get_active());
	return Result;
}
