/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifdef HAVE_CONFIG_H
 #include "../config.h"
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <list>
#include <cstdio>
#include <gtkmm/main.h>
#include <glibmm/i18n.h>
#ifdef HAVE_LIBCURL
#include <curl/curl.h>
#endif
#include "vifir.h"
#include "MainWindow.h"
#include "DisclaimerDialog.h"
#include "Config.h"
#include "Airport.h"
#include "NFD.h"
#include "Route.h"

int App::Run() {
	std::string GladeFilename;
	struct stat statbuf;
	Config Cfg;

	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
	textdomain(GETTEXT_PACKAGE);

#ifdef HAVE_LIBCURL
	if (curl_global_init(CURL_GLOBAL_ALL)!=0) {
		fprintf(stderr,"%s\n",(Glib::ustring(_("Error initializing CURL library - aborting."))).c_str());
		return 1;
	}
#endif

	if (!Cfg.Load()) {
		/* Ignore, use defaults */
	}

	/* Try a local file */
	GladeFilename="vifir.glade";
	if (stat(GladeFilename.c_str(),&statbuf)!=0) {
		/* Try a system file */
		GladeFilename=Cfg.GetPackageDataDir()+"/vifir.glade";
	}

	DisclaimerDialog *Disclaimer=new DisclaimerDialog(&GladeFilename);
	if (Disclaimer->GetInitFailure()==false && Disclaimer->Run()==true) {
		delete Disclaimer;
		MainWindow Window(this,&GladeFilename,&Cfg);
		Gtk::Main::run(*Window.GetGtkWindow());
	} else {
		delete Disclaimer;
	}

#ifdef HAVE_LIBCURL
	curl_global_cleanup();
#endif

	return 0;
}

int main(int argc, char **argv) {
	Gtk::Main kit(&argc,&argv);
	App Application;
	return Application.Run();
}
